=======
Authors
=======
Authors of Handyscope, in chronological order:

* Tim Hetkämper <hetkaemper@emt.uni-paderborn.de>
* Johannes Deuse-Kleinsteuber
* Fabian Woitschek
* Leander Claes <claes@emt.uni-paderborn.de>
* Kevin Koch